==> emodpy-1.4.0-py3-none-any.whl: tests/test_slurm.py <==
"""

Test Intent and Design

Test basic EMOD functionality on SLURM.
- Config is crafted via callback, using json-based defaults for now.
- Three additional parameters are set here in "user space" beyond the default params.
- The campaign is a simple outbreak.
- EP4 is on but the scripts are the defaults, so they don't 'do' anythying, except a lot of emod_api imports. So
  emod-api neeeds to be 'installed' in the Assets.
- Then we are doing a sweep over 2 Run_Numbers and a few Base_Infectivity values.
- There is some serialization stuff in this test but it's set to occur at a timestep this scenario does not reach.
- Test success is simply run to completion witout error.
NOTE: I don't like that a test is getting a lot of input files from examples. 
"""
import os

import pytest
from idmtools.entities.experiment import Experiment

from idmtools.assets import Asset, AssetCollection  #
from idmtools.builders import SimulationBuilder
from idmtools.core.platform_factory import Platform
from idmtools.entities.templated_simulation import TemplatedSimulations
from idmtools_test.utils.itest_with_persistence import ITestWithPersistence
from idmtools_platform_comps.utils.python_requirements_ac.requirements_to_asset_collection import RequirementsToAssetCollection

#from emodpy.defaults.schema import Schema
from emodpy.defaults.emod_sir import EMODSir
from emodpy.emod_task import EMODTask
from emodpy.generic.serialization import add_serialization_timesteps
from examples.config_update_parameters import config_update_params

current_directory = os.path.dirname(os.path.realpath(__file__))
BIN_PATH = os.path.join(current_directory, "..", "examples", "inputs", "bin")
INPUT_PATH = os.path.join(current_directory, "..", "examples", "emod_demographics", "inputs")

num_seeds = 2
sim_duration = 3

def set_config_params_fn( task, default ): # ignore the default (maybe)
    # TBD: Do this with emod_api and poi
    print( "Building config.json for test_slurm." )
    task.config = default.config( task.eradication_path )
    task.set_parameter("Config_Name", "test slurm sim")
    task.set_parameter("Enable_Termination_On_Zero_Total_Infectivity", 0) 
    task.set_parameter("Minimum_End_Time", 10) 
    return task


@pytest.mark.skip('this test is replaced by other tests in the same folder')
@pytest.mark.comps
class TestSerialization(ITestWithPersistence):
    def setUp(self) -> None:
        self.case_name = os.path.basename(__file__) + "--" + self._testMethodName
        print(self.case_name)
        self.platform = Platform("SLURM")

        self.pl = RequirementsToAssetCollection(self.platform, requirements_path="./inputs/requirements.txt")

    def test_basic_experiment_in_slurm(self):
        task = EMODTask.from_default(
            #default=Schema(),
            default=EMODSir(), # use hard-coded json
            eradication_path=os.path.join(BIN_PATH, "Eradication"),
            param_custom_cb=set_config_params_fn,
        )
        task.legacy_exe = True

        # Remove default demographic files from EMODSir's config Demographics_Filenames
        task.demographics.clear()
        demo_file = os.path.join(INPUT_PATH, "demographics.json")

        # Add new demographic file from local to experiment level( Assets dir in comps's)
        task.demographics.add_demographics_from_file(demo_file)

        # Add serialization parameters
        # I don't think this is happening because we're not running long enough.
        timesteps = [sim_duration * 365]
        add_serialization_timesteps(task=task, timesteps=timesteps, end_at_final=False, use_absolute_times=False)

        # Create TemplatedSimulations with task
        ts = TemplatedSimulations(base_task=task)

        # Create SimulationBuilder
        builder = SimulationBuilder()
        # Add sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Run_Number"), range(num_seeds))
        # Add another sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Base_Infectivity"), [0.6, 1.0, 1.5, 2.0])

        # Add builder to templated simulations
        ts.add_builder(builder)

        # Create experiment from template
        experiment = Experiment.from_template(ts, name=self.case_name)
        other_assets = AssetCollection.from_id(self.pl.run())
        experiment.assets.add_assets(other_assets)

        # The last step is to call run_items() on the platform to run the simulations.
        self.platform.run_items(experiment)
        self.platform.wait_till_done(experiment)
        self.assertTrue(experiment.succeeded, "expected experiment succeeded")

==> emodpy-1.19.0.dev8-py3-none-any.whl: tests/test_slurm.py <==
"""

Test Intent and Design

Test basic EMOD functionality on SLURM.
- Config is crafted via callback, using json-based defaults for now.
- Three additional parameters are set here in "user space" beyond the default params.
- The campaign is a simple outbreak.
- EP4 is on but the scripts are the defaults, so they don't 'do' anythying, except a lot of emod_api imports. So
  emod-api neeeds to be 'installed' in the Assets.
- Then we are doing a sweep over 2 Run_Numbers and a few Base_Infectivity values.
- There is some serialization stuff in this test but it's set to occur at a timestep this scenario does not reach.
- Test success is simply run to completion witout error.
NOTE: I don't like that a test is getting a lot of input files from examples. 
"""
import os

import pytest
from idmtools.entities.experiment import Experiment

from idmtools.assets import AssetCollection
from idmtools.builders import SimulationBuilder
from idmtools.core.platform_factory import Platform
from idmtools.entities.templated_simulation import TemplatedSimulations
from idmtools_test.utils.itest_with_persistence import ITestWithPersistence
from idmtools_platform_comps.utils.python_requirements_ac.requirements_to_asset_collection import RequirementsToAssetCollection

# from emodpy.defaults.schema import Schema
from emodpy.defaults.emod_sir import EMODSir
from emodpy.emod_task import EMODTask
from emodpy.generic.serialization import add_serialization_timesteps

current_directory = os.path.dirname(os.path.realpath(__file__))
BIN_PATH = os.path.join(current_directory, "..", "examples", "inputs", "bin")
INPUT_PATH = os.path.join(current_directory, "..", "examples", "emod_demographics", "inputs")

num_seeds = 2
sim_duration = 3


def set_config_params_fn(task, default):  # ignore the default (maybe)
    # TBD: Do this with emod_api and poi
    print("Building config.json for test_slurm.")
    task.config = default.config(task.eradication_path)
    task.set_parameter("Config_Name", "test slurm sim")
    task.set_parameter("Enable_Termination_On_Zero_Total_Infectivity", 0) 
    task.set_parameter("Minimum_End_Time", 10) 
    return task


@pytest.mark.skip('this test is replaced by other tests in the same folder')
@pytest.mark.comps
class TestSerialization(ITestWithPersistence):
    def setUp(self) -> None:
        self.case_name = os.path.basename(__file__) + "--" + self._testMethodName
        print(self.case_name)
        self.platform = Platform("SLURM")

        self.pl = RequirementsToAssetCollection(self.platform, requirements_path="./inputs/requirements.txt")

    def test_basic_experiment_in_slurm(self):
        task = EMODTask.from_default(
            # default=Schema(),
            default=EMODSir(),  # use hard-coded json
            eradication_path=os.path.join(BIN_PATH, "Eradication"),
            param_custom_cb=set_config_params_fn,
        )
        task.legacy_exe = True

        # Remove default demographic files from EMODSir's config Demographics_Filenames
        task.demographics.clear()
        demo_file = os.path.join(INPUT_PATH, "demographics.json")

        # Add new demographic file from local to experiment level(Assets dir in comps's)
        task.demographics.add_demographics_from_file(demo_file)

        # Add serialization parameters
        # I don't think this is happening because we're not running long enough.
        timesteps = [sim_duration * 365]
        add_serialization_timesteps(task=task, timesteps=timesteps, end_at_final=False, use_absolute_times=False)

        # Create TemplatedSimulations with task
        ts = TemplatedSimulations(base_task=task)

        # Create SimulationBuilder
        builder = SimulationBuilder()
        # Add sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Run_Number"), range(num_seeds))
        # Add another sweep parameter to builder
        builder.add_sweep_definition(EMODTask.set_parameter_partial("Base_Infectivity"), [0.6, 1.0, 1.5, 2.0])

        # Add builder to templated simulations
        ts.add_builder(builder)

        # Create experiment from template
        experiment = Experiment.from_template(ts, name=self.case_name)
        other_assets = AssetCollection.from_id(self.pl.run())
        experiment.assets.add_assets(other_assets)

        # The last step is to call run_items() on the platform to run the simulations.
        self.platform.run_items(experiment)
        self.platform.wait_till_done(experiment)
        self.assertTrue(experiment.succeeded, "expected experiment succeeded")
